Documentation
¶
Index ¶
Constants ¶
const ( ColorCmd = "color" JoinCmd = "join" LeaveCmd = "leave" WeatherCmd = "weather" ShutdownCmd = "shutdown" ColorOption = "color" GroupOption = "group" LocationOption = "location" ForecastOption = "forecast" )
Constants related to the bot's discord commands and their options
Variables ¶
This section is empty.
Functions ¶
func Fahrenheit ¶
Fahrenheit converts celsius to fahrenheit
func Forecast ¶
func Forecast(place string, forecast ForecastType) (ret string, err error)
Forecast returns a forecast for a location, or an error if something goes wrong. The forecast parameter specifies the type of forecast we want.
Types ¶
type DiscordUI ¶
type DiscordUI struct {
// contains filtered or unexported fields
}
DiscordUI holds data needed to interact with Discord.
func NewDiscordUI ¶
NewDiscordUI returns a new DiscordUI object.
type ForecastType ¶
type ForecastType int
ForecastType indicates what type of forecast the user wants.
const ( CurrentForecast ForecastType = iota // The current conditions TodayForecast // Today's forecast WeekForecast // The forecast for the next week )
Constants representing which forecast the user is requesting
Click to show internal directories.
Click to hide internal directories.